;+
;NAME:
;       plot_ssw_fov
;PURPOSE:
;       Plot fields of view of selected instruments from catalogs
;SAMPLE CALLING SEQUENCE:
;       plot_ssw_fov,st_time,en_time     [,/trace][,/sxt][,/all]
;	plot_ssw_fov,'4-jun-98 01:00','4-jun-98 02:00',/trace
;INPUTS:
;       st_time     - start time 
;	en_time     - end time
;Keyword Inputs:
;       sxt         - if set, Yohkoh/SXT FOV
;       trace       - if set, TRACE FOV
;       eit         - if set, SoHO/EIT FOV - not implimented
;       cds         - if set, SoHO/CDS FOV - not implimented
;       all         - if set, plot all available FOVs  (the default)
;PROCEDURE:
;       Reads catalogs for the selected instruments
;       Plots FOV of each on outline of solar disk
;RESTRICTIONS:
;	Required catalogs must be on line and the approriate environment 
;	variables defined.
;HISTORY:
;       Written    Feb-99 by R.D.Bentley
;-

pro	plot_ssw_fov, sttim, entim, sxt=sxt, trace=trace, eit=eit, cds=cds, $
			all=all, debug=debug

if n_params() eq 0 then begin
  sttim = '1-jul-98 01:00'
  entim = '1-jul-98 02:00'
endif

range = anytim2ints([sttim,entim])
if keyword_set(debug) then help,/st,range

do_all = keyword_set(all)
if (not keyword_set(sxt)) and (not keyword_set(trace)) $
   and (not keyword_set(eit)) and (not keyword_set(cds)) then do_all = 1
if do_all then box_message,'PLOT_SSW_FOV - Plotting all available FOVs'

;	create the window and setup scales

loadct,3,/silent
window,xsiz=500,ysiz=500
!p.position=[0.1,0.1,0.9,0.9]
;;plot,[0,1],[0,1],psym=1,pos=[0.07,0.06,0.95*8.2/11.,0.94],/nodata,          $
plot,[0,1],[0,1],psym=1,xstyle=1,ystyle=1,/nodata,           $
      xtitle='Solar EW (arc min)',                           $
      ytitle='Solar NS (arc min)',                           $
      xrange=[-20.,20.],                                     $
      yrange=[-20.,20.],                                     $
      title='Start-time ' + sttim + ', End-time ' + entim ;+ '!C' + seq_nam

;	outline solar limb

rr = get_rb0p(range)
rad = total(rr(0,*))/60. / n_elements(range)
xcir = cos(2*!pi*findgen(400)/399)
ycir = sin(2*!pi*findgen(400)/399)
oplot, xcir*rad, ycir*rad
empty

;>>>	TRACE images

if keyword_set(trace) or do_all then begin 

   print,''
   box_message,'Plot TRACE FOV'

   trace_cat,sttim,entim,cat
   help,cat
   if keyword_set(debug) then help,/st,cat

   sz = size(cat)
   if n_elements(sz) eq 4 then begin

      print,'Trace wavelengths: ',cat(uniq(cat.wave_len,sort(cat.wave_len))).wave_len

      x = cat.xcen/60.
      y = cat.ycen/60.
      dx = cat.CDELT1/60.
      dy = dx				;.CDELT2 not always there
      xfov = cat.NAXIS1*dx		;cat.CDELT1/60.
      yfov = cat.NAXIS2*dy		;cat.CDELT2/60.

      if (n_elements(x) eq 1) then begin
          x = x*(fltarr(2)+1) ;make it into an array
          y = y*(fltarr(2)+1) ;make it into an array
          xfov = xfov*(fltarr(2)+1) ;make it into an array
          yfov = yfov*(fltarr(2)+1) ;make it into an array
      end

      oplot,x,y,psym=1
      for i=0,n_elements(x)-1 do begin
           draw_boxcensiz, x(i), y(i), xfov(i), yfov(i), /data
      endfor

   endif else print,'NO TRACE data in the time interval'

endif

;>>>	YOHKOH/SXT images

if keyword_set(sxt) or do_all then begin 

   print,''
   box_message,'Plot YOHKOH/SXT FOV'

   rd_obs,sttim,entim,bcs0,sxtf0,sxtp0,w_h0,fid0,/sxtf,/sxtp
   help,sxtp0
   if keyword_set(debug) then help,/st,sxtp0
   struct = sxtp0

   sz = size(struct)
   if n_elements(sz) eq 4 then begin

   fov_center = gt_center(struct, /angle)/60.  	;acrminutes from sun center
   x = fov_center(0,*) 
   y = fov_center(1,*)

   sum = 2^gt_res(struct)
   shape_cmd = gt_shape(struct, /obs_region)
   xfov = shape_cmd(0,*)*sum*!ys_sxtpix/60.              ;size of the plot window in arcminutes
   yfov = shape_cmd(1,*)*sum*!ys_sxtpix/60.

   if (n_elements(x) eq 1) then begin
       x = x*(fltarr(2)+1) ;make it into an array
       y = y*(fltarr(2)+1) ;make it into an array
       xfov = xfov*(fltarr(2)+1) ;make it into an array
       yfov = yfov*(fltarr(2)+1) ;make it into an array
   end

   oplot,x,y,psym=1,color=150
   for i=0,n_elements(struct)-1 do begin
           draw_boxcensiz, x(i), y(i), xfov(i), yfov(i), /data, color=150
   end

   endif else print,'NO YOHKOH/SXT data in the time interval'

endif

;>>>	SOHO/EIT images

if keyword_set(eit) or do_all then begin 

   print,''
;   box_message,'Plot SOHO/EIT FOV'
   box_message,'SOHO/EIT not yet implimented'

endif

;>>>	SOHO/CDS images

if keyword_set(cds) or do_all then begin 

   print,''
;   box_message,'Plot SOHO/EIT FOV'
   box_message,'SOHO/CDS not yet implimented'

endif

end
